@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2018 NVIDIA Corporation
+    Copyright (c) 2018-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -21,6 +21,7 @@
 
 *******************************************************************************/
 
+#include "uvm8_api.h"
 #include "uvm8_lock.h"
 #include "uvm8_kvmalloc.h"
 #include "uvm8_va_space.h"
@@ -357,15 +358,20 @@ static void npu_release(struct npu_context *npu_context, void *va_mm)
     uvm_va_space_mm_shutdown(va_space_mm);
 }
 
+static void npu_release_entry(struct npu_context *npu_context, void *va_mm)
+{
+    UVM_ENTRY_VOID(npu_release(npu_context, va_mm));
+}
+
 #ifdef NV_PNV_NPU2_INIT_CONTEXT_CALLBACK_RETURNS_VOID
     static struct npu_context *pnv_npu2_init_context_wrapper(struct pci_dev *gpdev, unsigned long flags, void *priv)
     {
-        return pnv_npu2_init_context(gpdev, flags, npu_release, priv);
+        return pnv_npu2_init_context(gpdev, flags, npu_release_entry, priv);
     }
 #else
     static struct npu_context *npu_release_ret(struct npu_context *npu_context, void *va_mm)
     {
-        npu_release(npu_context, va_mm);
+        npu_release_entry(npu_context, va_mm);
 
         // The NPU code doesn't do anything with this returned value
         return NULL;
