@@ -1355,7 +1355,7 @@ static NV_STATUS create_big_page_identity_mapping(uvm_gpu_t *gpu)
 {
     NvU64 base = gpu->big_page.identity_mapping.base;
     NvU32 big_page_size = gpu->big_page.internal_size;
-    NvU64 size = UVM_ALIGN_UP(gpu->vidmem_max_allocatable_address + 1, big_page_size);
+    NvU64 size = UVM_ALIGN_UP(gpu->mem_info.max_allocatable_address + 1, big_page_size);
 
     UVM_ASSERT(gpu->big_page.swizzling);
     UVM_ASSERT(base);
@@ -1386,18 +1386,16 @@ NV_STATUS uvm_mmu_create_peer_identity_mappings(uvm_gpu_t *gpu, uvm_gpu_t *peer)
     NvU32 page_size;
     NvU64 size;
     uvm_aperture_t aperture;
-    NvU32 peer_index;
-    NvU64 base;
     NvU64 phys_offset;
+    uvm_gpu_identity_mapping_t *peer_mapping;
 
-    if (gpu->peer_copy_mode != UVM_GPU_PEER_COPY_MODE_VIRTUAL)
+    if (gpu->peer_copy_mode != UVM_GPU_PEER_COPY_MODE_VIRTUAL || peer->mem_info.size == 0)
         return NV_OK;
 
     page_size = uvm_mmu_biggest_page_size(&gpu->address_space_tree);
-    size = UVM_ALIGN_UP(peer->vidmem_max_allocatable_address + 1, page_size);
+    size = UVM_ALIGN_UP(peer->mem_info.max_allocatable_address + 1, page_size);
     aperture = uvm_gpu_peer_aperture(gpu, peer);
-    peer_index = uvm_gpu_index(peer->id);
-    base = gpu->peer_mappings[peer_index].base;
+    peer_mapping = uvm_gpu_get_peer_mapping(gpu, peer->id);
     phys_offset = 0ULL;
 
     if (uvm_gpus_are_nvswitch_connected(gpu, peer)) {
@@ -1409,15 +1407,15 @@ NV_STATUS uvm_mmu_create_peer_identity_mappings(uvm_gpu_t *gpu, uvm_gpu_t *peer)
     UVM_ASSERT(page_size);
     UVM_ASSERT(size);
     UVM_ASSERT(size <= UVM_PEER_IDENTITY_VA_SIZE);
-    UVM_ASSERT(base);
+    UVM_ASSERT(peer_mapping->base);
 
     return create_identity_mapping(gpu,
-                                   base,
+                                   peer_mapping->base,
                                    size,
                                    aperture,
                                    phys_offset,
                                    page_size,
-                                   &gpu->peer_mappings[peer_index].range_vec);
+                                   &peer_mapping->range_vec);
 }
 
 void uvm_mmu_destroy_big_page_identity_mappings(uvm_gpu_t *gpu)
@@ -1435,7 +1433,7 @@ void uvm_mmu_destroy_big_page_identity_mappings(uvm_gpu_t *gpu)
 void uvm_mmu_destroy_peer_identity_mappings(uvm_gpu_t *gpu, uvm_gpu_t *peer)
 {
     if (gpu->peer_copy_mode == UVM_GPU_PEER_COPY_MODE_VIRTUAL) {
-        uvm_gpu_identity_mapping_t *mapping = gpu->peer_mappings + uvm_gpu_index(peer->id);
+        uvm_gpu_identity_mapping_t *mapping = uvm_gpu_get_peer_mapping(gpu, peer->id);
 
         if (mapping->range_vec)
             (void)uvm_page_table_range_vec_clear_ptes(mapping->range_vec, UVM_MEMBAR_SYS);
@@ -1476,14 +1474,16 @@ static void mmu_init_gpu_chunk_sizes(uvm_gpu_t *gpu)
 static void mmu_init_gpu_peer_addresses(uvm_gpu_t *gpu)
 {
     if (gpu->peer_copy_mode == UVM_GPU_PEER_COPY_MODE_VIRTUAL) {
-        NvU32 i;
-        for (i = 0; i < UVM_MAX_GPUS; i++) {
-            gpu->peer_mappings[i].base = gpu->rm_va_base +
-                                         gpu->rm_va_size +
-                                         UVM_PEER_IDENTITY_VA_SIZE * i;
+        uvm_gpu_id_t gpu_id;
+
+        for_each_gpu_id(gpu_id) {
+            uvm_gpu_get_peer_mapping(gpu, gpu_id)->base = gpu->rm_va_base +
+                                                          gpu->rm_va_size +
+                                                          UVM_PEER_IDENTITY_VA_SIZE * uvm_id_gpu_index(gpu_id);
         }
 
-        UVM_ASSERT(gpu->uvm_mem_va_base >= gpu->peer_mappings[UVM_MAX_GPUS - 1].base + UVM_PEER_IDENTITY_VA_SIZE);
+        UVM_ASSERT(gpu->uvm_mem_va_base >=
+                   uvm_gpu_get_peer_mapping(gpu, uvm_gpu_id(UVM_ID_MAX_GPUS - 1))->base + UVM_PEER_IDENTITY_VA_SIZE);
     }
 }
 
