@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2018 NVIDIA Corporation
+    Copyright (c) 2018-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -22,9 +22,8 @@
 *******************************************************************************/
 
 #include "uvm_common.h"
+#include "uvm_ioctl.h"
 #include "uvm_linux.h"
-#include "uvm_linux_ioctl.h"
-#include "uvm8_init.h"
 #include "uvm8_lock.h"
 #include "uvm8_api.h"
 #include "uvm8_va_range.h"
