@@ -9,7 +9,7 @@
  */
  
 #include "nv-msi.h"
-#include "nv-instance.h"
+#include "nv-proto.h"
 
 #if defined(NV_LINUX_PCIE_MSI_SUPPORTED)
 void NV_API_CALL nv_init_msi(nv_state_t *nv)
