@@ -203,7 +203,7 @@ static NvU64 nv_get_max_sysmem_address(void)
     NvU64 global_max_pfn = 0ULL;
     int node_id;
 
-    NV_FOR_EACH_ONLINE_NODE(node_id)
+    for_each_online_node(node_id)
     {
         global_max_pfn = max(global_max_pfn, nv_node_end_pfn(node_id));
     }
